Crate suture_driver

Crate suture_driver 

SutureDriver trait and registry for format-specific drivers.

Drivers translate between file formats and semantic patches, enabling Suture to understand what changed rather than just which bytes changed.

Re-exports

pub use error::DriverError;
pub use plugin::BuiltinDriverPlugin;
pub use plugin::DriverPlugin;
pub use plugin::PluginError;
pub use plugin::PluginRegistry;
pub use registry::DriverRegistry;
pub use types::DiffHunk;
pub use types::DiffHunkType;
pub use types::DiffSummary;
pub use types::VisualDiff;

Modules

error
plugin
registry
types

Enums

SemanticChange
A single semantic change detected by a driver.

Traits

SutureDriver
Format-specific driver for translating between file formats and Suture patches.